=======================
``referencing-loaders``
=======================

|PyPI| |Pythons| |CI|

.. |PyPI| image:: https://img.shields.io/pypi/v/referencing-loaders.svg
  :alt: PyPI version
  :target: https://pypi.org/project/referencing-loaders/

.. |Pythons| image:: https://img.shields.io/pypi/pyversions/referencing-loaders.svg
  :alt: Supported Python versions
  :target: https://pypi.org/project/referencing-loaders/

.. |CI| image:: https://github.com/python-jsonschema/referencing-loaders/workflows/CI/badge.svg
  :alt: Build status
  :target: https://github.com/python-jsonschema/referencing-loaders/actions?query=workflow%3ACI

Experimental additional loaders for helping to build ``referencing.Registry`` objects out of various places.

Will likely merge into the ``referencing`` package when it's clear that what's here is "right".
